/*
*
* Copyright (c) 2004 Sun Microsystems, Inc.
* All rights reserved.
* You may not modify, use, reproduce, or distribute this software except in compliance with the terms
* of the License at: http://developer.sun.com/berkeley_license.html
* Author : Sameer Tyagi, Sun Microsystems s.t@sun.com
* "Patterns and Strategies for Building Document-Based Web Services"
*  http://java.sun.com/developer/technicalArticles/xml/jaxrpcpatterns
*/

import  com.examples.nodatabinding.*;

import java.math.BigDecimal;
import java.util.Calendar;


public class WSDLClient {

    public static void main(String[] args) throws Exception {
        String url = "http://localhost:9090/nodatabindingjaxb/jaxrpc";
        if (args.length == 1) {
            url = args[0];
        }
        POService_Impl serviceproxy = new POService_Impl();
        IPurchaseOrder_Stub stub = (IPurchaseOrder_Stub) (serviceproxy.getIPurchaseOrderPort());
        stub._setProperty(javax.xml.rpc.Stub.ENDPOINT_ADDRESS_PROPERTY, url);
        sendPurchaseOrder(stub);
    }


    /**
     * Sends a purchaseorder to the service
     *
     * @param stub
     * @throws java.rmi.RemoteException
     */
    private static void sendPurchaseOrder(IPurchaseOrder_Stub stub) throws java.rmi.RemoteException {

        Address addrs = new Address("1 Main Street", "Beverly Hills", "CA", "90210");
        LineItem items[] = new LineItem[]{
            new LineItem("Copier Paper", new BigDecimal(10.00), 2),
            new LineItem("Toner", new BigDecimal(920.00), 1)};

        PurchaseOrder order = new PurchaseOrder();
        order.setCreateDate(Calendar.getInstance());
        order.setBillTo(addrs);
        order.setShipTo(addrs);
        order.setItems(items);
        order.setPoID("ABC-CO-19282");

        try {
            PurchaseOrderStatus result = stub.acceptPO(order);
            System.out.println("Order id is : " + result.getOrderid());
            System.out.println("Timestamp is : " + result.getTimestamp());
        } catch (POProcessingProblem e1) {
            System.out.println("Problem processing PO on the web service : " + e1);
        }
    }


}
